@@ -1,22 +1,14 @@
-#![feature(test)]
-
-#[macro_use]
-extern crate failure;
-#[macro_use]
-extern crate pyo3;
-extern crate serde;
-extern crate serde_derive;
-extern crate serde_json;
-extern crate test;
-
 use std::collections::BTreeMap;
 use std::fmt;
 use std::marker::PhantomData;
+use failure::Fail;
 
 use pyo3::prelude::*;
 use pyo3::exceptions::TypeError as PyTypeError;
 use pyo3::exceptions::ValueError as PyValueError;
 use pyo3::types::{PyDict, PyFloat, PyList, PyAny, PyTuple};
+use pyo3::{import_exception, wrap_pyfunction};
+
 use serde::de::{self, DeserializeSeed, Deserializer, MapAccess, SeqAccess, Visitor};
 use serde::ser::{self, Serialize, SerializeMap, SerializeSeq, Serializer};
 
@@ -551,25 +543,4 @@ impl<'de, 'a> Visitor<'de> for HyperJsonValue<'a> {
 
         Ok(entries.to_object(self.py))
     }
-}
-
-#[cfg(test)]
-mod tests {
-    use std::fs;
-    use test::Bencher;
-
-    use super::*;
-
-    #[bench]
-    fn bench_dict_string_int_pairs(b: &mut Bencher) {
-        let dict_string_int = fs::read_to_string("benchmark/dict_string_int_plain.txt").unwrap();
-
-        let gil = Python::acquire_gil();
-        let py = gil.python();
-
-        b.iter(|| {
-            let obj = dict_string_int.to_object(py);
-            loads_impl(py, obj, None, None, None, None, None, None)
-        });
-    }
-}
+}
\ No newline at end of file
